@@ -12,6 +12,7 @@ KNOWN_SCOPES = {
     "search": "urn:globus:auth:scope:search.api.globus.org:search",
     "search_ingest": "urn:globus:auth:scope:search.api.globus.org:all",
     "data_mdf": "urn:globus:auth:scope:data.materialsdatafacility.org:all",
+    "mdf_connect_dev": "https://auth.globus.org/scopes/0e0a9538-ce45-43c1-998a-d3a7031a83f0/connect",
     "mdf_connect": "https://auth.globus.org/scopes/c17f27bb-f200-486a-b785-2a25e82af505/connect",
     "petrel": "https://auth.globus.org/scopes/56ceac29-e98a-440a-a594-b41e7a084b62/all",
     "groups": "urn:globus:auth:scope:nexus.api.globus.org:groups",
@@ -52,7 +53,7 @@ def anonymous_login(services):
     # Initialize valid services
     for serv in services:
         try:
-            clients[serv] = KNOWN_CLIENTS[serv](http_timeout=STD_TIMEOUT)
+            clients[serv] = KNOWN_CLIENTS[serv]()
         except KeyError:  # No known client
             print("Error: No known client for '{}' service.".format(serv))
         except Exception:  # Other issue, probably auth
@@ -116,7 +117,7 @@ def confidential_login(services, client_id, client_secret, make_clients=True):
 
         # User wants clients and client supported
         if make_clients and scope in KNOWN_CLIENTS.keys():
-            returnables[key] = KNOWN_CLIENTS[scope](authorizer=auth, http_timeout=STD_TIMEOUT)
+            returnables[key] = KNOWN_CLIENTS[scope](authorizer=auth)
         # Returning authorizer only
         else:
             returnables[key] = auth
@@ -202,7 +203,7 @@ def login(services, make_clients=True, clear_old_tokens=False, **kwargs):
 
         # User wants clients and client supported
         if make_clients and scope in KNOWN_CLIENTS.keys():
-            returnables[key] = KNOWN_CLIENTS[scope](authorizer=auth, http_timeout=STD_TIMEOUT)
+            returnables[key] = KNOWN_CLIENTS[scope](authorizer=auth)
         # Returning authorizer only
         else:
             returnables[key] = auth
